*Synthesis Problem with 30 processes
*One Period (t=1)
*Convex Hull Version

$TITLE     Synthesis Problem
$OFFSYMXREF
$OFFSYMLIST
$ONINLINE

*See process flowsheet for stream labeling

************************************************************************************************************************
*************************************************** DECLARATIONS *******************************************************
************************************************************************************************************************


******************************************************* SETS ***********************************************************

SETS

K            /1*70/                       /* Number of Synthesis Streams */
I            /1*30/                       /* Number of Synthesis Processes */
D            /1*2/                        /* Number of disjuncts per disjunction for Synthesis portion */
E            /1*4/                        /* Maximum number of equations within every disjunct of every disjunction for Synthesis portion - used only for indexing big-M parameters */
;

*Epsilon used in the reformulation of non-linear constraints in disjunctions.
SCALAR  ES      /1E-6/;

***************************************************** VARIABLES *******************************************************

VARIABLES

obj                                      /*Objective function variable (in $)*/
;

POSITIVE VARIABLES

X(K),V(K,D,I)
;

BINARY VARIABLES

Z(I)
;

****************************************************** DATA FOR RETROFIT PORTION *****************************************************

PARAMETER PC(K)              /* Cost coefficient in objective (Cost and revenue of raw material and products, respectively) */

               /1       -1
                2       0
                3       0
                4       0
                5       0
                6       0
                7       5
                8       0
                9       0
                10      0
                11      0
                12      -2
                13      0
                14      0
                15      0
                16      0
                17      0
                18      0
                19      0
                20      0
                21      0
                22      0
                23      0
                24      0
                25      0
                26      0
                27      0
                28      0
                29      -10
                30      -5
                31      0
                32      0
                33      0
                34      0
                35      0
                36      0
                37      40
                38      15
                39      10
                40      30
                41      35
                42      20
                43      25
                44      15
                45      0
                46      0
                47      0
                48      0
                49      0
                50      0
                51      0
                52      30
                53      0
                54      0
                55      0
                56      0
                57      -1
                58      0
                59      0
                60      0
                61      0
                62      0
                63      0
                64      0
                65      80
                66      285
                67      290
                68      280
                69      290
                70      350/

PARAMETER FC(I)             /* Fixed costs in objective */

               /1       -5
                2       -8
                3       -6
                4       -10
                5       -6
                6       -7
                7       -4
                8       -5
                9       -2
                10      -4
                11      -3
                12      -7
                13      -3
                14      -2
                15      -4
                16      -2
                17      -3
                18      -5
                19      -2
                20      -1
                21      -2
                22      -9
                23      -5
                24      -2
                25      -10
                26      -4
                27      -7
                28      -4
                29      -2
                30      -8/
;

PARAMETER UB(K,D,I) /1*70 .1*2 .1*30 = 0/;

*Note: The bounds available on X('1'), X('12'), X('29'), X('30'), X('57'), X('74') and X('75') were written as X1_UP, X12_UP, X29_UP, X30_UP, X57_UP, X74_UP and X75_UP below in order to generate the optimal upper bounds on the disaggregated variables.


SCALARS
X1_UP /0/
X12_UP /0/
X29_UP /0/
X30_UP /0/
X57_UP /0/;

X1_UP = 40;
X12_UP = 30;
X29_UP = 20;
X30_UP = 20;
X57_UP = 30;

UB('2','1','1') = X1_UP;
UB('2','2','1') = X1_UP;
UB('4','1','1') = LOG(1+X1_UP);
UB('4','2','1') = LOG(1+X1_UP);

UB('3','1','2') = X1_UP;
UB('3','2','2') = X1_UP;
UB('5','1','2') = 1.2*LOG(1+X1_UP);
UB('5','2','2') = 1.2*LOG(1+X1_UP);

UB('9','1','3') = 1.2*LOG(1+X1_UP);
UB('9','2','3') = 1.2*LOG(1+X1_UP);
UB('13','1','3') = 0.75*1.2*LOG(1+X1_UP);
UB('13','2','3') = 0.75*1.2*LOG(1+X1_UP);

UB('10','1','4') = 1.2*LOG(1+X1_UP);
UB('10','2','4') = 1.2*LOG(1+X1_UP);
UB('14','1','4') = 1.5*LOG(1+(1.2*LOG(1+X1_UP)));
UB('14','2','4') = 1.5*LOG(1+(1.2*LOG(1+X1_UP)));

UB('11','1','5') = 1.2*LOG(1+X1_UP);
UB('11','2','5') = 1.2*LOG(1+X1_UP);
UB('12','1','5') = X12_UP;
UB('12','2','5') = X12_UP;
UB('15','1','5') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('15','2','5') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);

UB('16','1','6') = 0.75*1.2*LOG(1+X1_UP);
UB('16','2','6') = 0.75*1.2*LOG(1+X1_UP);
UB('21','1','6') = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('21','2','6') = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)));

UB('17','1','7') = 0.75*1.2*LOG(1+X1_UP);
UB('17','2','7') = 0.75*1.2*LOG(1+X1_UP);
UB('22','1','7') = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('22','2','7') = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)));

UB('14','1','8') = 1.5*LOG(1+(1.2*LOG(1+X1_UP)));
UB('14','2','8') = 1.5*LOG(1+(1.2*LOG(1+X1_UP)));
UB('23','1','8') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));
UB('23','2','8') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));

UB('18','1','9') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('18','2','9') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('24','1','9') = 0.9*(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP));
UB('24','2','9') = 0.9*(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP));

UB('19','1','10') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('19','2','10') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('25','1','10') = 0.6*(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP));
UB('25','2','10') = 0.6*(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP));

UB('20','1','11') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('20','2','11') = MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP);
UB('26','1','11') = 1.1*LOG(1+(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP)));
UB('26','2','11') = 1.1*LOG(1+(MAX(1.2*LOG(1+X1_UP), 0.5*X12_UP)));

UB('21','1','12') = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('21','2','12') = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('29','1','12') = X29_UP;
UB('29','2','12') = X29_UP;
UB('37','1','12') = MAX(0.9*(1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)))), X29_UP);
UB('37','2','12') = MAX(0.9*(1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP)))), X29_UP);

UB('22','1','13') = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('22','2','13') = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)));
UB('38','1','13') = LOG(1+(0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)))));
UB('38','2','13') = LOG(1+(0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP)))));

UB('27','1','14') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));
UB('27','2','14') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));
UB('39','1','14') = 0.7*LOG(1+(LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))))));
UB('39','2','14') = 0.7*LOG(1+(LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))))));

UB('28','1','15') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));
UB('28','2','15') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))));
UB('31','1','15') = X30_UP + 0.9*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('31','2','15') = X30_UP + 0.9*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('40','1','15') = MAX(0.65*LOG(1+LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))))), 0.65*LOG(1+ (X30_UP + 0.9*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('40','2','15') = MAX(0.65*LOG(1+LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP)))))), 0.65*LOG(1+ (X30_UP + 0.9*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));

UB('32','1','16') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('32','2','16') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('41','1','16') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('41','2','16') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);

UB('33','1','17') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('33','2','17') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('42','1','17') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);
UB('42','2','17') = 0.6*MAX(1.2*LOG(1+X1_UP),0.5*X12_UP);

UB('34','1','18') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('34','2','18') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('43','1','18') = 0.75*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('43','2','18') = 0.75*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));

UB('35','1','19') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('35','2','19') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('44','1','19') = 0.8*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('44','2','19') = 0.8*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));

UB('36','1','20') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('36','2','20') = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP));
UB('45','1','20') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('45','2','20') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));

*For values of UB in the range of 21-40, simply replace the upper bound of X('1') wherever it's present in 1-20 with the upper bound of X('45') (i.e. replace X1_UB with 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))
UB('47','1','21') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('47','2','21') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('49','1','21') = LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('49','2','21') = LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));

UB('48','1','22') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('48','2','22') = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))));
UB('50','1','22') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('50','2','22') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));

UB('54','1','23') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('54','2','23') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('58','1','23') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('58','2','23') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));

UB('55','1','24') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('55','2','24') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('59','1','24') = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));
UB('59','2','24') = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));

UB('56','1','25') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('56','2','25') = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('57','1','25') = X57_UP;
UB('57','2','25') = X57_UP;
UB('60','1','25') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('60','2','25') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);

UB('61','1','26') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('61','2','26') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('66','1','26') = 1.25*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));
UB('66','2','26') = 1.25*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));

UB('62','1','27') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('62','2','27') = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))));
UB('67','1','27') = 0.9*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));
UB('67','2','27') = 0.9*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));

UB('59','1','28') = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));
UB('59','2','28') = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))));
UB('68','1','28') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))))));
UB('68','2','28') = LOG(1+(1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP)))))))));

UB('63','1','29') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('63','2','29') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('69','1','29') = 0.9*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('69','2','29') = 0.9*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);

UB('64','1','30') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('64','2','30') = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('70','1','30') = 0.6*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);
UB('70','2','30') = 0.6*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP),0.5*X12_UP))))), 0.5*X57_UP);



****************************************************** EQUATIONS ******************************************************

EQUATIONS

Objective

MB1,MB2,MB3,MB4,MB5,MB6,MB7,MB8,MB9,MB10,
MB11,MB12,MB13,MB14,MB15,MB16,MB17


DISJ_1_1_1
DISJ_1_2_1
DISJ_2_2_1
DISJ_1_3_1
DISJ_2_3_1
DISJ_1_4_1
DISJ_2_4_1
DISJ_3_4_1
DISJ_4_4_1

DISJ_1_1_2
DISJ_1_2_2
DISJ_2_2_2
DISJ_1_3_2
DISJ_2_3_2
DISJ_1_4_2
DISJ_2_4_2
DISJ_3_4_2
DISJ_4_4_2

DISJ_1_1_3
DISJ_1_2_3
DISJ_2_2_3
DISJ_1_3_3
DISJ_2_3_3
DISJ_1_4_3
DISJ_2_4_3
DISJ_3_4_3
DISJ_4_4_3

DISJ_1_1_4
DISJ_1_2_4
DISJ_2_2_4
DISJ_1_3_4
DISJ_2_3_4
DISJ_1_4_4
DISJ_2_4_4
DISJ_3_4_4
DISJ_4_4_4

DISJ_1_1_5
DISJ_2_1_5
DISJ_1_2_5
DISJ_2_2_5
DISJ_3_2_5
DISJ_1_3_5
DISJ_2_3_5
DISJ_3_3_5
DISJ_1_4_5
DISJ_2_4_5
DISJ_3_4_5
DISJ_4_4_5
DISJ_5_4_5
DISJ_6_4_5

DISJ_1_1_6
DISJ_1_2_6
DISJ_2_2_6
DISJ_1_3_6
DISJ_2_3_6
DISJ_1_4_6
DISJ_2_4_6
DISJ_3_4_6
DISJ_4_4_6

DISJ_1_1_7
DISJ_1_2_7
DISJ_2_2_7
DISJ_1_3_7
DISJ_2_3_7
DISJ_1_4_7
DISJ_2_4_7
DISJ_3_4_7
DISJ_4_4_7

DISJ_1_1_8
DISJ_1_2_8
DISJ_2_2_8
DISJ_1_3_8
DISJ_2_3_8
DISJ_1_4_8
DISJ_2_4_8
DISJ_3_4_8
DISJ_4_4_8

DISJ_1_1_9
DISJ_1_2_9
DISJ_2_2_9
DISJ_1_3_9
DISJ_2_3_9
DISJ_1_4_9
DISJ_2_4_9
DISJ_3_4_9
DISJ_4_4_9

DISJ_1_1_10
DISJ_1_2_10
DISJ_2_2_10
DISJ_1_3_10
DISJ_2_3_10
DISJ_1_4_10
DISJ_2_4_10
DISJ_3_4_10
DISJ_4_4_10

DISJ_1_1_11
DISJ_1_2_11
DISJ_2_2_11
DISJ_1_3_11
DISJ_2_3_11
DISJ_1_4_11
DISJ_2_4_11
DISJ_3_4_11
DISJ_4_4_11

DISJ_1_1_12
DISJ_2_1_12
DISJ_1_2_12
DISJ_2_2_12
DISJ_3_2_12
DISJ_1_3_12
DISJ_2_3_12
DISJ_3_3_12
DISJ_1_4_12
DISJ_2_4_12
DISJ_3_4_12
DISJ_4_4_12
DISJ_5_4_12
DISJ_6_4_12

DISJ_1_1_13
DISJ_1_2_13
DISJ_2_2_13
DISJ_1_3_13
DISJ_2_3_13
DISJ_1_4_13
DISJ_2_4_13
DISJ_3_4_13
DISJ_4_4_13

DISJ_1_1_14
DISJ_1_2_14
DISJ_2_2_14
DISJ_1_3_14
DISJ_2_3_14
DISJ_1_4_14
DISJ_2_4_14
DISJ_3_4_14
DISJ_4_4_14

DISJ_1_1_15
DISJ_2_1_15
DISJ_1_2_15
DISJ_2_2_15
DISJ_3_2_15
DISJ_1_3_15
DISJ_2_3_15
DISJ_3_3_15
DISJ_1_4_15
DISJ_2_4_15
DISJ_3_4_15
DISJ_4_4_15
DISJ_5_4_15
DISJ_6_4_15

DISJ_1_1_16
DISJ_1_2_16
DISJ_2_2_16
DISJ_1_3_16
DISJ_2_3_16
DISJ_1_4_16
DISJ_2_4_16
DISJ_3_4_16
DISJ_4_4_16

DISJ_1_1_17
DISJ_1_2_17
DISJ_2_2_17
DISJ_1_3_17
DISJ_2_3_17
DISJ_1_4_17
DISJ_2_4_17
DISJ_3_4_17
DISJ_4_4_17

DISJ_1_1_18
DISJ_1_2_18
DISJ_2_2_18
DISJ_1_3_18
DISJ_2_3_18
DISJ_1_4_18
DISJ_2_4_18
DISJ_3_4_18
DISJ_4_4_18

DISJ_1_1_19
DISJ_1_2_19
DISJ_2_2_19
DISJ_1_3_19
DISJ_2_3_19
DISJ_1_4_19
DISJ_2_4_19
DISJ_3_4_19
DISJ_4_4_19

DISJ_1_1_20
DISJ_1_2_20
DISJ_2_2_20
DISJ_1_3_20
DISJ_2_3_20
DISJ_1_4_20
DISJ_2_4_20
DISJ_3_4_20
DISJ_4_4_20

DISJ_1_1_21
DISJ_1_2_21
DISJ_2_2_21
DISJ_1_3_21
DISJ_2_3_21
DISJ_1_4_21
DISJ_2_4_21
DISJ_3_4_21
DISJ_4_4_21

DISJ_1_1_22
DISJ_1_2_22
DISJ_2_2_22
DISJ_1_3_22
DISJ_2_3_22
DISJ_1_4_22
DISJ_2_4_22
DISJ_3_4_22
DISJ_4_4_22

DISJ_1_1_23
DISJ_1_2_23
DISJ_2_2_23
DISJ_1_3_23
DISJ_2_3_23
DISJ_1_4_23
DISJ_2_4_23
DISJ_3_4_23
DISJ_4_4_23

DISJ_1_1_24
DISJ_1_2_24
DISJ_2_2_24
DISJ_1_3_24
DISJ_2_3_24
DISJ_1_4_24
DISJ_2_4_24
DISJ_3_4_24
DISJ_4_4_24

DISJ_1_1_25
DISJ_2_1_25
DISJ_1_2_25
DISJ_2_2_25
DISJ_3_2_25
DISJ_1_3_25
DISJ_2_3_25
DISJ_3_3_25
DISJ_1_4_25
DISJ_2_4_25
DISJ_3_4_25
DISJ_4_4_25
DISJ_5_4_25
DISJ_6_4_25

DISJ_1_1_26
DISJ_1_2_26
DISJ_2_2_26
DISJ_1_3_26
DISJ_2_3_26
DISJ_1_4_26
DISJ_2_4_26
DISJ_3_4_26
DISJ_4_4_26

DISJ_1_1_27
DISJ_1_2_27
DISJ_2_2_27
DISJ_1_3_27
DISJ_2_3_27
DISJ_1_4_27
DISJ_2_4_27
DISJ_3_4_27
DISJ_4_4_27

DISJ_1_1_28
DISJ_1_2_28
DISJ_2_2_28
DISJ_1_3_28
DISJ_2_3_28
DISJ_1_4_28
DISJ_2_4_28
DISJ_3_4_28
DISJ_4_4_28

DISJ_1_1_29
DISJ_1_2_29
DISJ_2_2_29
DISJ_1_3_29
DISJ_2_3_29
DISJ_1_4_29
DISJ_2_4_29
DISJ_3_4_29
DISJ_4_4_29

DISJ_1_1_30
DISJ_1_2_30
DISJ_2_2_30
DISJ_1_3_30
DISJ_2_3_30
DISJ_1_4_30
DISJ_2_4_30
DISJ_3_4_30
DISJ_4_4_30


D1,
L1,L2,L3,L4,L5,L6,L7,L8,L9,L10,L11,L12,L13,L14,L15,L16,L17,L18,L19,L20
L21,L22,L23,L24,L25,L26,L27,L28,L29,L30,L31,L32,L33,L34,L35,L36,L37;

************************************************************************************************************************
*************************************************** OPTIMIZATION PROBLEM ***********************************************
************************************************************************************************************************

*Note: We multiply, where appropriate, the coefficents in the objective function by 1E3 in order to obtain our obj fn value in $.

Objective.. obj =E= SUM(I,FC(I)*Z(I)) + SUM(K,PC(K)*X(K));


*Mass Balances
MB1..    X('1')     -    X('2')  -    X('3')              =E= 0;
MB2..    X('6')     -    X('4')  -    X('5')              =E= 0;
MB3..    X('6')     -    X('7')  -    X('8')              =E= 0;
MB4..    X('8')     -    X('9')  -    X('10') -   X('11') =E= 0;
MB5..    X('13')    -    X('16') -    X('17')             =E= 0;
MB6..    X('15')    -    X('18') -    X('19') -   X('20') =E= 0;
MB7..    X('23')    -    X('27') -    X('28')             =E= 0;
MB8..    X('31')    -    X('24') -    X('30')             =E= 0;
MB9..    X('25')    -    X('32') -    X('33')             =E= 0;
MB10..   X('26')    -    X('34') -    X('35') -   X('36') =E= 0;

*Connecting Stream between flowsheets
MB11..   X('45')    -    X('46')                          =E= 0;

MB12..    X('46')     -    X('47')  -    X('48')                =E= 0;
MB13..    X('51')     -    X('49')  -    X('50')                =E= 0;
MB14..    X('51')     -    X('52')  -    X('53')                =E= 0;
MB15..    X('53')     -    X('54')  -    X('55') -   X('56')    =E= 0;
MB16..    X('58')     -    X('61')  -    X('62')                =E= 0;
MB17..    X('60')     -    X('63')  -    X('64') -   X('65')    =E= 0;

*Disjunctions
*Note 1: The non-linear constraints inside the disjunctions are technically equations, but relax as less than or equal to inequalities (from physical considerations, the greater than or equal to inequalities are nonsense), which is why this problem is convex.
*Note 2: The equations setting flows equal to 0 in the second disjunct relax solely as less than or equal to inequalities, since the greater than or equal to inequalities are redundant (and are thus omitted).
*Note 3: The non-linear constraints within each disjunction have been modififed from their original form in Lee & Grossmann's "New Algorithms for Non-Linear Generalized Disjunctive Programming" to the form presented in Sawaya & Grossmann's Short Note on the "Computational Implementation of the Non-Linear Convex Hull".

DISJ_1_1_1.. (Z('1')+ES)*(V('4','1','1')/(Z('1')+ES) - LOG(1+V('2','1','1')/(Z('1')+ES))) =L= 0;
DISJ_1_2_1.. V('2','2','1') =E= 0;
DISJ_2_2_1.. V('4','2','1') =E= 0;
DISJ_1_3_1.. X('2') =E= SUM(D,V('2',D,'1'));
DISJ_2_3_1.. X('4') =E= SUM(D,V('4',D,'1'));
DISJ_1_4_1.. V('2','1','1') =L= UB('2','1','1')*Z('1');
DISJ_2_4_1.. V('2','2','1') =L= UB('2','2','1')*(1-Z('1'));
DISJ_3_4_1.. V('4','1','1') =L= UB('4','1','1')*Z('1');
DISJ_4_4_1.. V('4','2','1') =L= UB('4','2','1')*(1-Z('1'));

DISJ_1_1_2.. (Z('2')+ES)*(V('5','1','2')/(Z('2')+ES) - 1.2*LOG(1+V('3','1','2')/(Z('2')+ES))) =L= 0;
DISJ_1_2_2.. V('3','2','2') =E= 0;
DISJ_2_2_2.. V('5','2','2') =E= 0;
DISJ_1_3_2.. X('3') =E= SUM(D,V('3',D,'2'));
DISJ_2_3_2.. X('5') =E= SUM(D,V('5',D,'2'));
DISJ_1_4_2.. V('3','1','2') =L= UB('3','1','2')*Z('2');
DISJ_2_4_2.. V('3','2','2') =L= UB('3','2','2')*(1-Z('2'));
DISJ_3_4_2.. V('5','1','2') =L= UB('5','1','2')*Z('2');
DISJ_4_4_2.. V('5','2','2') =L= UB('5','2','2')*(1-Z('2'));

DISJ_1_1_3.. V('13','1','3') - 0.75*V('9','1','3') =E= 0;
DISJ_1_2_3.. V('9','2','3') =E= 0;
DISJ_2_2_3.. V('13','2','3') =E= 0;
DISJ_1_3_3.. X('9') =E= SUM(D,V('9',D,'3'));
DISJ_2_3_3.. X('13') =E= SUM(D,V('13',D,'3'));
DISJ_1_4_3.. V('9','1','3') =L= UB('9','1','3')*Z('3');
DISJ_2_4_3.. V('9','2','3') =L= UB('9','2','3')*(1-Z('3'));
DISJ_3_4_3.. V('13','1','3') =L= UB('13','1','3')*Z('3');
DISJ_4_4_3.. V('13','2','3') =L= UB('13','2','3')*(1-Z('3'));

DISJ_1_1_4.. (Z('4')+ES)*(V('14','1','4')/(Z('4')+ES) - 1.5*LOG(1+V('10','1','4')/(Z('4')+ES))) =L= 0;
DISJ_1_2_4.. V('10','2','4') =E= 0;
DISJ_2_2_4.. V('14','2','4') =E= 0;
DISJ_1_3_4.. X('10') =E= SUM(D,V('10',D,'4'));
DISJ_2_3_4.. X('14') =E= SUM(D,V('14',D,'4'));
DISJ_1_4_4.. V('10','1','4') =L= UB('10','1','4')*Z('4');
DISJ_2_4_4.. V('10','2','4') =L= UB('10','2','4')*(1-Z('4'));
DISJ_3_4_4.. V('14','1','4') =L= UB('14','1','4')*Z('4');
DISJ_4_4_4.. V('14','2','4') =L= UB('14','2','4')*(1-Z('4'));

DISJ_1_1_5.. V('15','1','5') - V('11','1','5')  =E= 0;
DISJ_2_1_5.. V('15','1','5') - 0.5*V('12','1','5') =E= 0;
DISJ_1_2_5.. V('11','2','5') =E= 0;
DISJ_2_2_5.. V('12','2','5') =E= 0;
DISJ_3_2_5.. V('15','2','5') =E= 0;
DISJ_1_3_5.. X('11') =E= SUM(D,V('11',D,'5'));
DISJ_2_3_5.. X('12') =E= SUM(D,V('12',D,'5'));
DISJ_3_3_5.. X('15') =E= SUM(D,V('15',D,'5'));
DISJ_1_4_5.. V('11','1','5') =L= UB('11','1','5')*Z('5');
DISJ_2_4_5.. V('11','2','5') =L= UB('11','2','5')*(1-Z('5'));
DISJ_3_4_5.. V('12','1','5') =L= UB('12','1','5')*Z('5');
DISJ_4_4_5.. V('12','2','5') =L= UB('12','2','5')*(1-Z('5'));
DISJ_5_4_5.. V('15','1','5') =L= UB('15','1','5')*Z('5');
DISJ_6_4_5.. V('15','2','5') =L= UB('15','2','5')*(1-Z('5'));

DISJ_1_1_6.. (Z('6')+ES)*(V('21','1','6')/(Z('6')+ES) - 1.25*LOG(1+V('16','1','6')/(Z('6')+ES))) =L= 0;
DISJ_1_2_6.. V('16','2','6') =E= 0;
DISJ_2_2_6.. V('21','2','6') =E= 0;
DISJ_1_3_6.. X('16') =E= SUM(D,V('16',D,'6'));
DISJ_2_3_6.. X('21') =E= SUM(D,V('21',D,'6'));
DISJ_1_4_6.. V('16','1','6') =L= UB('16','1','6')*Z('6');
DISJ_2_4_6.. V('16','2','6') =L= UB('16','2','6')*(1-Z('6'));
DISJ_3_4_6.. V('21','1','6') =L= UB('21','1','6')*Z('6');
DISJ_4_4_6.. V('21','2','6') =L= UB('21','2','6')*(1-Z('6'));

DISJ_1_1_7.. (Z('7')+ES)*(V('22','1','7')/(Z('7')+ES) - 0.9*LOG(1+V('17','1','7')/(Z('7')+ES))) =L= 0;
DISJ_1_2_7.. V('17','2','7') =E= 0;
DISJ_2_2_7.. V('22','2','7') =E= 0;
DISJ_1_3_7.. X('17') =E= SUM(D,V('17',D,'7'));
DISJ_2_3_7.. X('22') =E= SUM(D,V('22',D,'7'));
DISJ_1_4_7.. V('17','1','7') =L= UB('17','1','7')*Z('7');
DISJ_2_4_7.. V('17','2','7') =L= UB('17','2','7')*(1-Z('7'));
DISJ_3_4_7.. V('22','1','7') =L= UB('22','1','7')*Z('7');
DISJ_4_4_7.. V('22','2','7') =L= UB('22','2','7')*(1-Z('7'));

DISJ_1_1_8.. (Z('8')+ES)*(V('23','1','8')/(Z('8')+ES) - LOG(1+V('14','1','8')/(Z('8')+ES))) =L= 0;
DISJ_1_2_8.. V('14','2','8') =E= 0;
DISJ_2_2_8.. V('23','2','8') =E= 0;
DISJ_1_3_8.. X('14') =E= SUM(D,V('14',D,'8'));
DISJ_2_3_8.. X('23') =E= SUM(D,V('23',D,'8'));
DISJ_1_4_8.. V('14','1','8') =L= UB('14','1','8')*Z('8');
DISJ_2_4_8.. V('14','2','8') =L= UB('14','2','8')*(1-Z('8'));
DISJ_3_4_8.. V('23','1','8') =L= UB('23','1','8')*Z('8');
DISJ_4_4_8.. V('23','2','8') =L= UB('23','2','8')*(1-Z('8'));

DISJ_1_1_9.. V('24','1','9') - 0.9*V('18','1','9') =E= 0;
DISJ_1_2_9.. V('18','2','9') =E= 0;
DISJ_2_2_9.. V('24','2','9') =E= 0;
DISJ_1_3_9.. X('18') =E= SUM(D,V('18',D,'9'));
DISJ_2_3_9.. X('24') =E= SUM(D,V('24',D,'9'));
DISJ_1_4_9.. V('18','1','9') =L= UB('18','1','9')*Z('9');
DISJ_2_4_9.. V('18','2','9') =L= UB('18','2','9')*(1-Z('9'));
DISJ_3_4_9.. V('24','1','9') =L= UB('24','1','9')*Z('9');
DISJ_4_4_9.. V('24','2','9') =L= UB('24','2','9')*(1-Z('9'));

DISJ_1_1_10.. V('25','1','10') - 0.6*V('19','1','10') =E= 0;
DISJ_1_2_10.. V('19','2','10') =E= 0;
DISJ_2_2_10.. V('25','2','10') =E= 0;
DISJ_1_3_10.. X('19') =E= SUM(D,V('19',D,'10'));
DISJ_2_3_10.. X('25') =E= SUM(D,V('25',D,'10'));
DISJ_1_4_10.. V('19','1','10') =L= UB('19','1','10')*Z('10');
DISJ_2_4_10.. V('19','2','10') =L= UB('19','2','10')*(1-Z('10'));
DISJ_3_4_10.. V('25','1','10') =L= UB('25','1','10')*Z('10');
DISJ_4_4_10.. V('25','2','10') =L= UB('25','2','10')*(1-Z('10'));

DISJ_1_1_11.. (Z('11')+ES)*(V('26','1','11')/(Z('11')+ES) - 1.1*LOG(1+V('20','1','11')/(Z('11')+ES))) =L= 0;
DISJ_1_2_11.. V('20','2','11') =E= 0;
DISJ_2_2_11.. V('26','2','11') =E= 0;
DISJ_1_3_11.. X('20') =E= SUM(D,V('20',D,'11'));
DISJ_2_3_11.. X('26') =E= SUM(D,V('26',D,'11'));
DISJ_1_4_11.. V('20','1','11') =L= UB('20','1','11')*Z('11');
DISJ_2_4_11.. V('20','2','11') =L= UB('20','2','11')*(1-Z('11'));
DISJ_3_4_11.. V('26','1','11') =L= UB('26','1','11')*Z('11');
DISJ_4_4_11.. V('26','2','11') =L= UB('26','2','11')*(1-Z('11'));

DISJ_1_1_12.. V('37','1','12') - 0.9*V('21','1','12') =E= 0;
DISJ_2_1_12.. V('37','1','12') - V('29','1','12') =E= 0;
DISJ_1_2_12.. V('21','2','12') =E= 0;
DISJ_2_2_12.. V('29','2','12') =E= 0;
DISJ_3_2_12.. V('37','2','12') =E= 0;
DISJ_1_3_12.. X('21') =E= SUM(D,V('21',D,'12'));
DISJ_2_3_12.. X('29') =E= SUM(D,V('29',D,'12'));
DISJ_3_3_12.. X('37') =E= SUM(D,V('37',D,'12'));
DISJ_1_4_12.. V('21','1','12') =L= UB('21','1','12')*Z('12');
DISJ_2_4_12.. V('21','2','12') =L= UB('21','2','12')*(1-Z('12'));
DISJ_3_4_12.. V('29','1','12') =L= UB('29','1','12')*Z('12');
DISJ_4_4_12.. V('29','2','12') =L= UB('29','2','12')*(1-Z('12'));
DISJ_5_4_12.. V('37','1','12') =L= UB('37','1','12')*Z('12');
DISJ_6_4_12.. V('37','2','12') =L= UB('37','2','12')*(1-Z('12'));

DISJ_1_1_13.. (Z('13')+ES)*(V('38','1','13')/(Z('13')+ES) - LOG(1+V('22','1','13')/(Z('13')+ES))) =L= 0;
DISJ_1_2_13.. V('22','2','13') =E= 0;
DISJ_2_2_13.. V('38','2','13') =E= 0;
DISJ_1_3_13.. X('22') =E= SUM(D,V('22',D,'13'));
DISJ_2_3_13.. X('38') =E= SUM(D,V('38',D,'13'));
DISJ_1_4_13.. V('22','1','13') =L= UB('22','1','13')*Z('13');
DISJ_2_4_13.. V('22','2','13') =L= UB('22','2','13')*(1-Z('13'));
DISJ_3_4_13.. V('38','1','13') =L= UB('38','1','13')*Z('13');
DISJ_4_4_13.. V('38','2','13') =L= UB('38','2','13')*(1-Z('13'));

DISJ_1_1_14.. (Z('14')+ES)*(V('39','1','14')/(Z('14')+ES) - 0.7*LOG(1+V('27','1','14')/(Z('14')+ES))) =L= 0;
DISJ_1_2_14.. V('27','2','14') =E= 0;
DISJ_2_2_14.. V('39','2','14') =E= 0;
DISJ_1_3_14.. X('27') =E= SUM(D,V('27',D,'14'));
DISJ_2_3_14.. X('39') =E= SUM(D,V('39',D,'14'));
DISJ_1_4_14.. V('27','1','14') =L= UB('27','1','14')*Z('14');
DISJ_2_4_14.. V('27','2','14') =L= UB('27','2','14')*(1-Z('14'));
DISJ_3_4_14.. V('39','1','14') =L= UB('39','1','14')*Z('14');
DISJ_4_4_14.. V('39','2','14') =L= UB('39','2','14')*(1-Z('14'));

DISJ_1_1_15.. (Z('15')+ES)*(V('40','1','15')/(Z('15')+ES) - 0.65*LOG(1+(V('28','1','15'))/(Z('15')+ES))) =L= 0;
DISJ_2_1_15.. (Z('15')+ES)*(V('40','1','15')/(Z('15')+ES) - 0.65*LOG(1+(V('31','1','15'))/(Z('15')+ES))) =L= 0;
DISJ_1_2_15.. V('28','2','15') =E= 0;
DISJ_2_2_15.. V('31','2','15') =E= 0;
DISJ_3_2_15.. V('40','2','15') =E= 0;
DISJ_1_3_15.. X('28') =E= SUM(D,V('28',D,'15'));
DISJ_2_3_15.. X('31') =E= SUM(D,V('31',D,'15'));
DISJ_3_3_15.. X('40') =E= SUM(D,V('40',D,'15'));
DISJ_1_4_15.. V('28','1','15') =L= UB('28','1','15')*Z('15');
DISJ_2_4_15.. V('28','2','15') =L= UB('28','2','15')*(1-Z('15'));
DISJ_3_4_15.. V('31','1','15') =L= UB('31','1','15')*Z('15');
DISJ_4_4_15.. V('31','2','15') =L= UB('31','2','15')*(1-Z('15'));
DISJ_5_4_15.. V('40','1','15') =L= UB('40','1','15')*Z('15');
DISJ_6_4_15.. V('40','2','15') =L= UB('40','2','15')*(1-Z('15'));

DISJ_1_1_16.. V('41','1','16') - V('32','1','16') =E= 0;
DISJ_1_2_16.. V('32','2','16') =E= 0;
DISJ_2_2_16.. V('41','2','16') =E= 0;
DISJ_1_3_16.. X('32') =E= SUM(D,V('32',D,'16'));
DISJ_2_3_16.. X('41') =E= SUM(D,V('41',D,'16'));
DISJ_1_4_16.. V('32','1','16') =L= UB('32','1','16')*Z('16');
DISJ_2_4_16.. V('32','2','16') =L= UB('32','2','16')*(1-Z('16'));
DISJ_3_4_16.. V('41','1','16') =L= UB('41','1','16')*Z('16');
DISJ_4_4_16.. V('41','2','16') =L= UB('41','2','16')*(1-Z('16'));

DISJ_1_1_17.. V('42','1','17') - V('33','1','17') =E= 0;
DISJ_1_2_17.. V('33','2','17') =E= 0;
DISJ_2_2_17.. V('42','2','17') =E= 0;
DISJ_1_3_17.. X('33') =E= SUM(D,V('33',D,'17'));
DISJ_2_3_17.. X('42') =E= SUM(D,V('42',D,'17'));
DISJ_1_4_17.. V('33','1','17') =L= UB('33','1','17')*Z('17');
DISJ_2_4_17.. V('33','2','17') =L= UB('33','2','17')*(1-Z('17'));
DISJ_3_4_17.. V('42','1','17') =L= UB('42','1','17')*Z('17');
DISJ_4_4_17.. V('42','2','17') =L= UB('42','2','17')*(1-Z('17'));

DISJ_1_1_18.. (Z('18')+ES)*(V('43','1','18')/(Z('18')+ES) - 0.75*LOG(1+V('34','1','18')/(Z('18')+ES))) =L= 0;
DISJ_1_2_18.. V('34','2','18') =E= 0;
DISJ_2_2_18.. V('43','2','18') =E= 0;
DISJ_1_3_18.. X('34') =E= SUM(D,V('34',D,'18'));
DISJ_2_3_18.. X('43') =E= SUM(D,V('43',D,'18'));
DISJ_1_4_18.. V('34','1','18') =L= UB('34','1','18')*Z('18');
DISJ_2_4_18.. V('34','2','18') =L= UB('34','2','18')*(1-Z('18'));
DISJ_3_4_18.. V('43','1','18') =L= UB('43','1','18')*Z('18');
DISJ_4_4_18.. V('43','2','18') =L= UB('43','2','18')*(1-Z('18'));

DISJ_1_1_19.. (Z('19')+ES)*(V('44','1','19')/(Z('19')+ES) - 0.8*LOG(1+V('35','1','19')/(Z('19')+ES))) =L= 0;
DISJ_1_2_19.. V('35','2','19') =E= 0;
DISJ_2_2_19.. V('44','2','19') =E= 0;
DISJ_1_3_19.. X('35') =E= SUM(D,V('35',D,'19'));
DISJ_2_3_19.. X('44') =E= SUM(D,V('44',D,'19'));
DISJ_1_4_19.. V('35','1','19') =L= UB('35','1','19')*Z('19');
DISJ_2_4_19.. V('35','2','19') =L= UB('35','2','19')*(1-Z('19'));
DISJ_3_4_19.. V('44','1','19') =L= UB('44','1','19')*Z('19');
DISJ_4_4_19.. V('44','2','19') =L= UB('44','2','19')*(1-Z('19'));

DISJ_1_1_20.. (Z('20')+ES)*(V('45','1','20')/(Z('20')+ES) - 0.85*LOG(1+V('36','1','20')/(Z('20')+ES))) =L= 0;
DISJ_1_2_20.. V('36','2','20') =E= 0;
DISJ_2_2_20.. V('45','2','20') =E= 0;
DISJ_1_3_20.. X('36') =E= SUM(D,V('36',D,'20'));
DISJ_2_3_20.. X('45') =E= SUM(D,V('45',D,'20'));
DISJ_1_4_20.. V('36','1','20') =L= UB('36','1','20')*Z('20');
DISJ_2_4_20.. V('36','2','20') =L= UB('36','2','20')*(1-Z('20'));
DISJ_3_4_20.. V('45','1','20') =L= UB('45','1','20')*Z('20');
DISJ_4_4_20.. V('45','2','20') =L= UB('45','2','20')*(1-Z('20'));

*Form of disjunctions 21-30 is the same as that of first 20 disjunctions
DISJ_1_1_21.. (Z('21')+ES)*(V('49','1','21')/(Z('21')+ES) - LOG(1+V('47','1','21')/(Z('21')+ES))) =L= 0;
DISJ_1_2_21.. V('47','2','21') =E= 0;
DISJ_2_2_21.. V('49','2','21') =E= 0;
DISJ_1_3_21.. X('47') =E= SUM(D,V('47',D,'21'));
DISJ_2_3_21.. X('49') =E= SUM(D,V('49',D,'21'));
DISJ_1_4_21.. V('47','1','21') =L= UB('47','1','21')*Z('21');
DISJ_2_4_21.. V('47','2','21') =L= UB('47','2','21')*(1-Z('21'));
DISJ_3_4_21.. V('49','1','21') =L= UB('49','1','21')*Z('21');
DISJ_4_4_21.. V('49','2','21') =L= UB('49','2','21')*(1-Z('21'));

DISJ_1_1_22.. (Z('22')+ES)*(V('50','1','22')/(Z('22')+ES) - 1.2*LOG(1+V('48','1','22')/(Z('22')+ES))) =L= 0;
DISJ_1_2_22.. V('48','2','22') =E= 0;
DISJ_2_2_22.. V('50','2','22') =E= 0;
DISJ_1_3_22.. X('48') =E= SUM(D,V('48',D,'22'));
DISJ_2_3_22.. X('50') =E= SUM(D,V('50',D,'22'));
DISJ_1_4_22.. V('48','1','22') =L= UB('48','1','22')*Z('22');
DISJ_2_4_22.. V('48','2','22') =L= UB('48','2','22')*(1-Z('22'));
DISJ_3_4_22.. V('50','1','22') =L= UB('50','1','22')*Z('22');
DISJ_4_4_22.. V('50','2','22') =L= UB('50','2','22')*(1-Z('22'));

DISJ_1_1_23.. V('58','1','23') - 0.75*V('54','1','23') =E= 0;
DISJ_1_2_23.. V('54','2','23') =E= 0;
DISJ_2_2_23.. V('58','2','23') =E= 0;
DISJ_1_3_23.. X('54') =E= SUM(D,V('54',D,'23'));
DISJ_2_3_23.. X('58') =E= SUM(D,V('58',D,'23'));
DISJ_1_4_23.. V('54','1','23') =L= UB('54','1','23')*Z('23');
DISJ_2_4_23.. V('54','2','23') =L= UB('54','2','23')*(1-Z('23'));
DISJ_3_4_23.. V('58','1','23') =L= UB('58','1','23')*Z('23');
DISJ_4_4_23.. V('58','2','23') =L= UB('58','2','23')*(1-Z('23'));

DISJ_1_1_24.. (Z('24')+ES)*(V('59','1','24')/(Z('24')+ES) - 1.5*LOG(1+V('55','1','24')/(Z('24')+ES))) =L= 0;
DISJ_1_2_24.. V('55','2','24') =E= 0;
DISJ_2_2_24.. V('59','2','24') =E= 0;
DISJ_1_3_24.. X('55') =E= SUM(D,V('55',D,'24'));
DISJ_2_3_24.. X('59') =E= SUM(D,V('59',D,'24'));
DISJ_1_4_24.. V('55','1','24') =L= UB('55','1','24')*Z('24');
DISJ_2_4_24.. V('55','2','24') =L= UB('55','2','24')*(1-Z('24'));
DISJ_3_4_24.. V('59','1','24') =L= UB('59','1','24')*Z('24');
DISJ_4_4_24.. V('59','2','24') =L= UB('59','2','24')*(1-Z('24'));

DISJ_1_1_25.. V('60','1','25') - V('56','1','25') =E= 0;
DISJ_2_1_25.. V('60','1','25') - 0.5*V('57','1','25') =E= 0;
DISJ_1_2_25.. V('56','2','25') =E= 0;
DISJ_2_2_25.. V('57','2','25') =E= 0;
DISJ_3_2_25.. V('60','2','25') =E= 0;
DISJ_1_3_25.. X('56') =E= SUM(D,V('56',D,'25'));
DISJ_2_3_25.. X('57') =E= SUM(D,V('57',D,'25'));
DISJ_3_3_25.. X('60') =E= SUM(D,V('60',D,'25'));
DISJ_1_4_25.. V('56','1','25') =L= UB('56','1','25')*Z('25');
DISJ_2_4_25.. V('56','2','25') =L= UB('56','2','25')*(1-Z('25'));
DISJ_3_4_25.. V('57','1','25') =L= UB('57','1','25')*Z('25');
DISJ_4_4_25.. V('57','2','25') =L= UB('57','2','25')*(1-Z('25'));
DISJ_5_4_25.. V('60','1','25') =L= UB('60','1','25')*Z('25');
DISJ_6_4_25.. V('60','2','25') =L= UB('60','2','25')*(1-Z('25'));

DISJ_1_1_26.. (Z('26')+ES)*(V('66','1','26')/(Z('26')+ES) - 1.25*LOG(1+V('61','1','26')/(Z('26')+ES))) =L= 0;
DISJ_1_2_26.. V('61','2','26') =E= 0;
DISJ_2_2_26.. V('66','2','26') =E= 0;
DISJ_1_3_26.. X('61') =E= SUM(D,V('61',D,'26'));
DISJ_2_3_26.. X('66') =E= SUM(D,V('66',D,'26'));
DISJ_1_4_26.. V('61','1','26') =L= UB('61','1','26')*Z('26');
DISJ_2_4_26.. V('61','2','26') =L= UB('61','2','26')*(1-Z('26'));
DISJ_3_4_26.. V('66','1','26') =L= UB('66','1','26')*Z('26');
DISJ_4_4_26.. V('66','2','26') =L= UB('66','2','26')*(1-Z('26'));

DISJ_1_1_27.. (Z('27')+ES)*(V('67','1','27')/(Z('27')+ES) - 0.9*LOG(1+V('62','1','27')/(Z('27')+ES))) =L= 0;
DISJ_1_2_27.. V('62','2','27') =E= 0;
DISJ_2_2_27.. V('67','2','27') =E= 0;
DISJ_1_3_27.. X('62') =E= SUM(D,V('62',D,'27'));
DISJ_2_3_27.. X('67') =E= SUM(D,V('67',D,'27'));
DISJ_1_4_27.. V('62','1','27') =L= UB('62','1','27')*Z('27');
DISJ_2_4_27.. V('62','2','27') =L= UB('62','2','27')*(1-Z('27'));
DISJ_3_4_27.. V('67','1','27') =L= UB('67','1','27')*Z('27');
DISJ_4_4_27.. V('67','2','27') =L= UB('67','2','27')*(1-Z('27'));

DISJ_1_1_28.. (Z('28')+ES)*(V('68','1','28')/(Z('28')+ES) - LOG(1+V('59','1','28')/(Z('28')+ES))) =L= 0;
DISJ_1_2_28.. V('59','2','28') =E= 0;
DISJ_2_2_28.. V('68','2','28') =E= 0;
DISJ_1_3_28.. X('59') =E= SUM(D,V('59',D,'28'));
DISJ_2_3_28.. X('68') =E= SUM(D,V('68',D,'28'));
DISJ_1_4_28.. V('59','1','28') =L= UB('59','1','28')*Z('28');
DISJ_2_4_28.. V('59','2','28') =L= UB('59','2','28')*(1-Z('28'));
DISJ_3_4_28.. V('68','1','28') =L= UB('68','1','28')*Z('28');
DISJ_4_4_28.. V('68','2','28') =L= UB('68','2','28')*(1-Z('28'));

DISJ_1_1_29.. V('69','1','29') - 0.9*V('63','1','29') =E= 0;
DISJ_1_2_29.. V('63','2','29') =E= 0;
DISJ_2_2_29.. V('69','2','29') =E= 0;
DISJ_1_3_29.. X('63') =E= SUM(D,V('63',D,'29'));
DISJ_2_3_29.. X('69') =E= SUM(D,V('69',D,'29'));
DISJ_1_4_29.. V('63','1','29') =L= UB('63','1','29')*Z('29');
DISJ_2_4_29.. V('63','2','29') =L= UB('63','2','29')*(1-Z('29'));
DISJ_3_4_29.. V('69','1','29') =L= UB('69','1','29')*Z('29');
DISJ_4_4_29.. V('69','2','29') =L= UB('69','2','29')*(1-Z('29'));

DISJ_1_1_30.. V('70','1','30') - 0.6*V('64','1','30') =E= 0;
DISJ_1_2_30.. V('64','2','30') =E= 0;
DISJ_2_2_30.. V('70','2','30') =E= 0;
DISJ_1_3_30.. X('64') =E= SUM(D,V('64',D,'30'));
DISJ_2_3_30.. X('70') =E= SUM(D,V('70',D,'30'));
DISJ_1_4_30.. V('64','1','30') =L= UB('64','1','30')*Z('30');
DISJ_2_4_30.. V('64','2','30') =L= UB('64','2','30')*(1-Z('30'));
DISJ_3_4_30.. V('70','1','30') =L= UB('70','1','30')*Z('30');
DISJ_4_4_30.. V('70','2','30') =L= UB('70','2','30')*(1-Z('30'));

*Design Specifications
D1..  Z('1') + Z('2')                           =E= 1;

*Logic Cuts (that were deduced bZ inspection from the superstructure -- used to aid in the optimization)

L1..  -Z('3') + Z('6') + Z('7')                  =G= 0;
L2..  -Z('6') + Z('12')                          =G= 0;
L3..  -Z('7') + Z('13')                          =G= 0;
L4..  -Z('4') + Z('8')                           =G= 0;
L5..  -Z('8') + Z('14') + Z('15')                =G= 0;
L6..  -Z('5') + Z('9') + Z('10') + Z('11')       =G= 0;
L7..  -Z('9') + Z('15')                          =G= 0;
L8..  -Z('10') + Z('16') + Z('17')               =G= 0;
L9..  -Z('11') + Z('18') + Z('19') + Z('20')     =G= 0;
L10.. -Z('3') + Z('1') + Z('2')                  =G= 0;
L11.. -Z('4') + Z('1') + Z('2')                  =G= 0;
L12.. -Z('5') + Z('1') + Z('2')                  =G= 0;
L13.. -Z('6') + Z('3')                           =G= 0;
L14.. -Z('7') + Z('3')                           =G= 0;
L15.. -Z('8') + Z('4')                           =G= 0;
L16.. -Z('9') + Z('5')                           =G= 0;
L17.. -Z('10') + Z('5')                          =G= 0;
L18.. -Z('11') + Z('5')                          =G= 0;
L19.. -Z('12') + Z('6')                          =G= 0;
L20.. -Z('13') + Z('7')                          =G= 0;
L21.. -Z('14') + Z('8')                          =G= 0;
L22.. -Z('15') + Z('8')                          =G= 0;
L23.. -Z('16') + Z('10')                         =G= 0;
L24.. -Z('17') + Z('10')                         =G= 0;
L25.. -Z('18') + Z('11')                         =G= 0;
L26.. -Z('19') + Z('11')                         =G= 0;
L27.. -Z('20') + Z('11')                         =G= 0;

L28.. -Z('20') + Z('21') + Z('22')               =G= 0;
L29.. -Z('23') + Z('26') + Z('27')               =G= 0;
L30.. -Z('24') + Z('28')                         =G= 0;
L31.. -Z('21') + Z('20')                         =G= 0;
L32.. -Z('22') + Z('20')                         =G= 0;
L33.. -Z('26') + Z('23')                         =G= 0;
L34.. -Z('27') + Z('23')                         =G= 0;
L35.. -Z('28') + Z('24')                         =G= 0;
L36.. -Z('29') + Z('25')                         =G= 0;
L37.. -Z('30') + Z('25')                         =G= 0;

* Bounds
X.UP('1') = 40;
X.UP('12') = 30;
X.UP('29') = 20;
X.UP('30') = 20;
X.UP('57') = 30;

MODEL SYNTH_30_CH /ALL/;

OPTION LIMROW = 0;
OPTION LIMCOL = 0;
*OPTION SOLPRINT = OFF ;
*OPTION SYSOUT   = OFF ;
OPTION OPTCR = 0;
OPTION OPTCA = 0;
OPTION ITERLIM = 100000000;
OPTION RESLIM = 10800;
OPTION MIP = CPLEX;
OPTION RMINLP = CONOPT;
OPTION MINLP  = sbb;

*SOLVE RETROFIT_8_SYNTHESIS_30_CH USING RMINLP MAXIMIZING obj;

SYNTH_30_CH.NODLIM = 1000000;
SYNTH_30_CH.OPTFILE = 1;

SOLVE SYNTH_30_CH USING MINLP MAXIMIZING obj;
