*Synthesis Problem with 30 processes
*Three Periods (t=3)
*Big-M Version

$TITLE     Synthesis Problem
$OFFSYMXREF
$OFFSYMLIST
$ONINLINE

*See process flowsheet for stream labeling

************************************************************************************************************************
*************************************************** DECLARATIONS *******************************************************
************************************************************************************************************************


******************************************************* SETS ***********************************************************

SETS

T            /1*3/                        /*Time periods*/

I       /1*30/                            /* Number of process units */
K       /1*70/                            /* Number of streams */
D       /1*2/                             /* Number of disjuncts per disjunction */
E       /1*4/                             /* Maximum number of equations within every disjunct of every disjunction for Synthesis portion - used only for indexing big-M parameters */
;

ALIAS

(T,TAU)
;

***************************************************** VARIABLES *******************************************************

VARIABLES

obj                                      /*Objective function variable (in $)*/
X(K,T)
Z(I,T)
R(I,T)
COST(I,T)
;

POSITIVE VARIABLES

X(K,T)
V(K,D,I,T)
;

BINARY VARIABLES

Z(I,T)
R(I,T)
;

****************************************************** DATA ENTRY *****************************************************

TABLE PC(K,T)              /* Cost coefficient in objective (Cost and revenue of raw material and products, respectively) */
                        1       2       3
                1       -1      -1      -1
                2       0       0       0
                3       0       0       0
                4       0       0       0
                5       0       0       0
                6       0       0       0
                7       5       10      5
                8       0       0       0
                9       0       0       0
                10      0       0       0
                11      0       0       0
                12      -2      -1      -2
                13      0       0       0
                14      0       0       0
                15      0       0       0
                16      0       0       0
                17      0       0       0
                18      0       0       0
                19      0       0       0
                20      0       0       0
                21      0       0       0
                22      0       0       0
                23      0       0       0
                24      0       0       0
                25      0       0       0
                26      0       0       0
                27      0       0       0
                28      0       0       0
                29      -10     -5      -5
                30      -5      -5      -5
                31      0       0       0
                32      0       0       0
                33      0       0       0
                34      0       0       0
                35      0       0       0
                36      0       0       0
                37      40      30      15
                38      15      20      25
                39      10      30      40
                40      30      20      20
                41      35      50      20
                42      20      30      35
                43      25      50      10
                44      15      20      20
                45      0       0       0
                46      0       0       0
                47      0       0       0
                48      0       0       0
                49      0       0       0
                50      0       0       0
                51      0       0       0
                52      30      40      40
                53      0       0       0
                54      0       0       0
                55      0       0       0
                56      0       0       0
                57      -1      -1      -1
                58      0       0       0
                59      0       0       0
                60      0       0       0
                61      0       0       0
                62      0       0       0
                63      0       0       0
                64      0       0       0
                65      80      90      120
                66      285     390     350
                67      290     405     190
                68      280     400     430
                69      290     300     240
                70      350     250     300

TABLE FC(I,T)             /* Fixed costs in objective */
                         1       2       3
                1       -5       -4      -6
                2       -8       -7      -6
                3       -6       -9      -4
                4       -10      -9      -5
                5       -6       -10     -6
                6       -7       -7      -4
                7       -4       -3      -2
                8       -5       -6      -7
                9       -2       -5      -2
                10      -4       -7      -4
                11      -3       -9      -3
                12      -7       -2      -9
                13      -3       -1      -9
                14      -2       -6      -3
                15      -4       -8      -1
                16      -2       -5      -2
                17      -3       -4      -3
                18      -5       -7      -6
                19      -2       -8      -4
                20      -1       -4      -1
                21      -2       -5      -2
                22      -9       -2      -9
                23      -5       -8      -4
                24      -2       -3      -8
                25      -10      -6      -3
                26      -4       -8      -7
                27      -7       -3      -9
                28      -4       -8      -6
                29      -2       -1      -3
                30      -8       -3      -4
;

PARAMETERS BIGM(E,D,I,T) /1*4 .1*2 .1*30 .1*3 = 0/;

*Note 1: the values of the Big-M parameters below are optimal.
*Note 2: We could have fixed the values of M(E,'1',I) (i.e. big-M values in first disjuncts) to anything strictly greater than 0 since optimal M(E,'1',I) values are obtained when Y(I) is equal to 0, which would force all values of X(K) in that constraint to 0 (we chose M(E,'1',I) =1).
*Note 3: The bounds available on X('1'), X('12'), X('29') and X('30') were written as X1_UP, X12_UP, X29_UP and X30_UP below in order to generate the optimal Big-Ms.

PARAMETERS
X1_UP(T)
/1 = 40
 2 = 40
 3 = 40/

X12_UP(T)
/1 = 30
 2 = 30
 3 = 30/

X29_UP(T)
/1 = 20
 2 = 20
 3 = 20/

X30_UP(T)
/1 = 20
 2 = 20
 3 = 20/

X57_UP(T)
/1 = 30
 2 = 30
 3 = 30/;

BIGM('1','1','1',T) = 1;
BIGM('1','2','1',T) = X1_UP(T);
BIGM('2','2','1',T) = LOG(1+X1_UP(T));

BIGM('1','1','2',T) = 1;
BIGM('1','2','2',T) = X1_UP(T);
BIGM('2','2','2',T) = 1.2*LOG(1+X1_UP(T));

BIGM('1','1','3',T) = 1;
BIGM('2','1','3',T) = 1;
BIGM('1','2','3',T) = 1.2*LOG(1+X1_UP(T));
BIGM('2','2','3',T) = 0.75*1.2*LOG(1+X1_UP(T));

BIGM('1','1','4',T) = 1;
BIGM('1','2','4',T) = 1.2*LOG(1+X1_UP(T));
BIGM('2','2','4',T) = 1.5*LOG(1+(1.2*LOG(1+X1_UP(T))));

BIGM('1','1','5',T) = 1;
BIGM('2','1','5',T) = 1;
BIGM('3','1','5',T) = 1;
BIGM('4','1','5',T) = 1;
BIGM('1','2','5',T) = 1.2*LOG(1+X1_UP(T));
BIGM('2','2','5',T) = X12_UP(T);
BIGM('3','2','5',T) = MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));

BIGM('1','1','6',T) = 1;
BIGM('1','2','6',T) = 0.75*1.2*LOG(1+X1_UP(T));
BIGM('2','2','6',T) = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))));

BIGM('1','1','7',T) = 1;
BIGM('1','2','7',T) = 0.75*1.2*LOG(1+X1_UP(T));
BIGM('2','2','7',T) = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))));

BIGM('1','1','8',T) = 1;
BIGM('1','2','8',T) = 1.5*LOG(1+(1.2*LOG(1+X1_UP(T))));
BIGM('2','2','8',T) = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP(T))))));

BIGM('1','1','9',T) = 1;
BIGM('2','1','9',T) = 1;
BIGM('1','2','9',T) = MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('2','2','9',T) = 0.9*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));

BIGM('1','1','10',T) = 1;
BIGM('2','1','10',T) = 1;
BIGM('1','2','10',T) = MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('2','2','10',T) = 0.6*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));

BIGM('1','1','11',T) = 1;
BIGM('1','2','11',T) = MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('2','2','11',T) = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)));

BIGM('1','1','12',T) = 1;
BIGM('2','1','12',T) = 1;
BIGM('3','1','12',T) = 1;
BIGM('4','1','12',T) = 1;
BIGM('1','2','12',T) = 1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))));
BIGM('2','2','12',T) = X29_UP(T);
BIGM('3','2','12',T) = MAX(0.9*(1.25*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))))), X29_UP(T));

BIGM('1','1','13',T) = 1;
BIGM('1','2','13',T) = 0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))));
BIGM('2','2','13',T) = LOG(1+(0.9*LOG(1+(0.75*1.2*LOG(1+X1_UP(T))))));

BIGM('1','1','14',T) = 1;
BIGM('1','2','14',T) = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP(T))))));
BIGM('2','2','14',T) = 0.7*LOG(1+(LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP(T))))))));

BIGM('1','1','15',T) = 1;
BIGM('2','1','15',T) = 1;
BIGM('1','2','15',T) = LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP(T))))));
BIGM('2','2','15',T) = X30_UP(T) + 0.9*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('3','2','15',T) = MAX(0.65*LOG(1+LOG(1+(1.5*LOG(1+(1.2*LOG(1+X1_UP(T))))))), 0.65*LOG(1+ (X30_UP(T) + 0.9*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));

BIGM('1','1','16',T) = 1;
BIGM('2','1','16',T) = 1;
BIGM('1','2','16',T) = 0.6*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('2','2','16',T) = 0.6*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));

BIGM('1','1','17',T) = 1;
BIGM('2','1','17',T) = 1;
BIGM('1','2','17',T) = 0.6*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));
BIGM('2','2','17',T) = 0.6*MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T));

BIGM('1','1','18',T) = 1;
BIGM('1','2','18',T) = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)));
BIGM('2','2','18',T) = 0.75*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));

BIGM('1','1','19',T) = 1;
BIGM('1','2','19',T) = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)));
BIGM('2','2','19',T) = 0.8*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));

BIGM('1','1','20',T) = 1;
BIGM('1','2','20',T) = 1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)));
BIGM('2','2','20',T) = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));

BIGM('1','1','21',T) = 1;
BIGM('1','2','21',T) = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));
BIGM('2','2','21',T) = LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));

BIGM('1','1','22',T) = 1;
BIGM('1','2','22',T) = 0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))));
BIGM('2','2','22',T) = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));

BIGM('1','1','23',T) = 1;
BIGM('2','1','23',T) = 1;
BIGM('1','2','23',T) = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));
BIGM('2','2','23',T) = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));

BIGM('1','1','24',T) = 1;
BIGM('1','2','24',T) = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));
BIGM('2','2','24',T) = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))))));

BIGM('1','1','25',T) = 1;
BIGM('2','1','25',T) = 1;
BIGM('3','1','25',T) = 1;
BIGM('4','1','25',T) = 1;
BIGM('1','2','25',T) = 1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));
BIGM('2','2','25',T) = X57_UP(T);
BIGM('3','2','25',T) = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))))), 0.5*X57_UP(T));

BIGM('1','1','26',T) = 1;
BIGM('1','2','26',T) = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));
BIGM('2','2','26',T) = 1.25*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))))));

BIGM('1','1','27',T) = 1;
BIGM('1','2','27',T) = 0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))));
BIGM('2','2','27',T) = 0.9*LOG(1+(0.75*1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))))));

BIGM('1','1','28',T) = 1;
BIGM('1','2','28',T) = 1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))))));
BIGM('2','2','28',T) = LOG(1+(1.5*LOG(1+(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T))))))))));

BIGM('1','1','29',T) = 1;
BIGM('2','1','29',T) = 1;
BIGM('1','2','29',T) = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))))), 0.5*X57_UP(T));
BIGM('2','2','29',T) = 0.9*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))))), 0.5*X57_UP(T));

BIGM('1','1','30',T) = 1;
BIGM('2','1','30',T) = 1;
BIGM('1','2','30',T) = MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))))), 0.5*X57_UP(T));
BIGM('2','2','30',T) = 0.6*MAX(1.2*LOG(1+0.85*LOG(1+(1.1*LOG(1+MAX(1.2*LOG(1+X1_UP(T)),0.5*X12_UP(T)))))), 0.5*X57_UP(T));

TABLE BIGM2_1(I,T)
                        1       2      3
                1       5       4      6
                2       8       7      6
                3       6       9      4
                4       10      9      5
                5       6       10     6
                6       7       7      4
                7       4       3      2
                8       5       6      7
                9       2       5      2
                10      4       7      4
                11      3       9      3
                12      7       2      9
                13      3       1      9
                14      2       6      3
                15      4       8      1
                16      2       5      2
                17      3       4      3
                18      5       7      6
                19      2       8      4
                20      1       4      1
                21      2       5      2
                22      9       2      9
                23      5       8      4
                24      2       3      8
                25      10      6      3
                26      4       8      7
                27      7       3      9
                28      4       8      6
                29      2       1      3
                30      8       3      4
;
TABLE BIGM2_2(I,T)
                         1       2       3
                1       -5       -4      -6
                2       -8       -7      -6
                3       -6       -9      -4
                4       -10      -9      -5
                5       -6       -10     -6
                6       -7       -7      -4
                7       -4       -3      -2
                8       -5       -6      -7
                9       -2       -5      -2
                10      -4       -7      -4
                11      -3       -9      -3
                12      -7       -2      -9
                13      -3       -1      -9
                14      -2       -6      -3
                15      -4       -8      -1
                16      -2       -5      -2
                17      -3       -4      -3
                18      -5       -7      -6
                19      -2       -8      -4
                20      -1       -4      -1
                21      -2       -5      -2
                22      -9       -2      -9
                23      -5       -8      -4
                24      -2       -3      -8
                25      -10      -6      -3
                26      -4       -8      -7
                27      -7       -3      -9
                28      -4       -8      -6
                29      -2       -1      -3
                30      -8       -3      -4
;


****************************************************** EQUATIONS ******************************************************

EQUATIONS

Objective

MB1(T),MB2(T),MB3(T),MB4(T),MB5(T),MB6(T),MB7(T),MB8(T),MB9(T),MB10(T),
MB11(T),MB12(T),MB13(T),MB14(T),MB15(T),MB16(T),MB17(T)

DISJ_1_1_1(T)
DISJ_1_2_1(T)
DISJ_2_2_1(T)

DISJ_1_1_2(T)
DISJ_1_2_2(T)
DISJ_2_2_2(T)

DISJ_1_1_3(T)
DISJ_2_1_3(T)
DISJ_1_2_3(T)
DISJ_2_2_3(T)

DISJ_1_1_4(T)
DISJ_1_2_4(T)
DISJ_2_2_4(T)

DISJ_1_1_5(T)
DISJ_2_1_5(T)
DISJ_3_1_5(T)
DISJ_4_1_5(T)
DISJ_1_2_5(T)
DISJ_2_2_5(T)
DISJ_3_2_5(T)

DISJ_1_1_6(T)
DISJ_1_2_6(T)
DISJ_2_2_6(T)

DISJ_1_1_7(T)
DISJ_1_2_7(T)
DISJ_2_2_7(T)

DISJ_1_1_8(T)
DISJ_1_2_8(T)
DISJ_2_2_8(T)

DISJ_1_1_9(T)
DISJ_2_1_9(T)
DISJ_1_2_9(T)
DISJ_2_2_9(T)

DISJ_1_1_10(T)
DISJ_2_1_10(T)
DISJ_1_2_10(T)
DISJ_2_2_10(T)

DISJ_1_1_11(T)
DISJ_1_2_11(T)
DISJ_2_2_11(T)

DISJ_1_1_12(T)
DISJ_2_1_12(T)
DISJ_3_1_12(T)
DISJ_4_1_12(T)
DISJ_1_2_12(T)
DISJ_2_2_12(T)
DISJ_3_2_12(T)

DISJ_1_1_13(T)
DISJ_1_2_13(T)
DISJ_2_2_13(T)

DISJ_1_1_14(T)
DISJ_1_2_14(T)
DISJ_2_2_14(T)

DISJ_1_1_15(T)
DISJ_2_1_15(T)
DISJ_1_2_15(T)
DISJ_2_2_15(T)
DISJ_3_2_15(T)

DISJ_1_1_16(T)
DISJ_2_1_16(T)
DISJ_1_2_16(T)
DISJ_2_2_16(T)

DISJ_1_1_17(T)
DISJ_2_1_17(T)
DISJ_1_2_17(T)
DISJ_2_2_17(T)

DISJ_1_1_18(T)
DISJ_1_2_18(T)
DISJ_2_2_18(T)

DISJ_1_1_19(T)
DISJ_1_2_19(T)
DISJ_2_2_19(T)

DISJ_1_1_20(T)
DISJ_1_2_20(T)
DISJ_2_2_20(T)

DISJ_1_1_21(T)
DISJ_1_2_21(T)
DISJ_2_2_21(T)

DISJ_1_1_22(T)
DISJ_1_2_22(T)
DISJ_2_2_22(T)

DISJ_1_1_23(T)
DISJ_2_1_23(T)
DISJ_1_2_23(T)
DISJ_2_2_23(T)

DISJ_1_1_24(T)
DISJ_1_2_24(T)
DISJ_2_2_24(T)

DISJ_1_1_25(T)
DISJ_2_1_25(T)
DISJ_3_1_25(T)
DISJ_4_1_25(T)
DISJ_1_2_25(T)
DISJ_2_2_25(T)
DISJ_3_2_25(T)

DISJ_1_1_26(T)
DISJ_1_2_26(T)
DISJ_2_2_26(T)

DISJ_1_1_27(T)
DISJ_1_2_27(T)
DISJ_2_2_27(T)

DISJ_1_1_28(T)
DISJ_1_2_28(T)
DISJ_2_2_28(T)

DISJ_1_1_29(T)
DISJ_2_1_29(T)
DISJ_1_2_29(T)
DISJ_2_2_29(T)

DISJ_1_1_30(T)
DISJ_2_1_30(T)
DISJ_1_2_30(T)
DISJ_2_2_30(T)

DISJ2_1_Synthesis(I,T)
DISJ2_2_Synthesis(I,T)

Logic_Z(I,T,TAU)
Logic_R(I,T,TAU)
Logic_ZR(I,T)

D1(T)
L1(T),L2(T),L3(T),L4(T),L5(T),L6(T),L7(T),L8(T),L9(T),L10(T),L11(T),L12(T),L13(T),L14(T),L15(T),L16(T),L17(T),L18(T),L19(T),L20(T)
L21(T),L22(T),L23(T),L24(T),L25(T),L26(T),L27(T),L28(T),L29(T),L30(T),L31(T),L32(T),L33(T),L34(T),L35(T),L36(T),L37(T)
;

************************************************************************************************************************
*************************************************** OPTIMIZATION PROBLEM ***********************************************
************************************************************************************************************************

*Note: We multiply, where appropriate, the coefficents in the objective function by 1E3 in order to obtain our obj fn value in $.

Objective.. obj =E= SUM(T,SUM(I,FC(I,T)*R(I,T))) + SUM(T,SUM(K,PC(K,T)*X(K,T)));

*Mass Balances
MB1(T)..    X('1',T)     -    X('2',T)  -    X('3',T)                    =E= 0;
MB2(T)..    X('6',T)     -    X('4',T)  -    X('5',T)                    =E= 0;
MB3(T)..    X('6',T)     -    X('7',T)  -    X('8',T)                    =E= 0;
MB4(T)..    X('8',T)     -    X('9',T)  -    X('10',T) -   X('11',T)     =E= 0;
MB5(T)..    X('13',T)    -    X('16',T) -    X('17',T)                   =E= 0;
MB6(T)..    X('15',T)    -    X('18',T) -    X('19',T) -   X('20',T)     =E= 0;
MB7(T)..    X('23',T)    -    X('27',T) -    X('28',T)                   =E= 0;
MB8(T)..    X('31',T)    -    X('24',T) -    X('30',T)                   =E= 0;
MB9(T)..    X('25',T)    -    X('32',T) -    X('33',T)                   =E= 0;
MB10(T)..   X('26',T)    -    X('34',T) -    X('35',T) -   X('36',T)     =E= 0;

*Connecting Stream between flowsheets
MB11(T)..   X('45',T)    -    X('46',T)                                  =E= 0;

MB12(T)..    X('46',T)     -    X('47',T)  -    X('48',T)                =E= 0;
MB13(T)..    X('51',T)     -    X('49',T)  -    X('50',T)                =E= 0;
MB14(T)..    X('51',T)     -    X('52',T)  -    X('53',T)                =E= 0;
MB15(T)..    X('53',T)     -    X('54',T)  -    X('55',T) -   X('56',T)  =E= 0;
MB16(T)..    X('58',T)     -    X('61',T)  -    X('62',T)                =E= 0;
MB17(T)..    X('60',T)     -    X('63',T)  -    X('64',T) -   X('65',T)  =E= 0;

*Disjunctions
*Note 1: The non-linear constraints inside the disjunctions are technically equations, but relax as less than or equal to inequalities (from physical considerations, the greater than or equal to inequalities are nonsense), which is why this problem is convex.
*Note 2: The equations setting flows equal to 0 in the second disjunct relax solely as less than or equal to inequalities, since the greater than or equal to inequalities are redundant (and are thus omitted).
DISJ_1_1_1(T).. X('4',T) =L= LOG(1+X('2',T)) + BIGM('1','1','1',T)*(1-Z('1',T));
DISJ_1_2_1(T).. X('2',T) =L= BIGM('1','2','1',T)*Z('1',T);
DISJ_2_2_1(T).. X('4',T) =L= BIGM('2','2','1',T)*Z('1',T);

DISJ_1_1_2(T).. X('5',T) =L= 1.2*LOG(1+X('3',T)) + BIGM('1','1','2',T)*(1-Z('2',T)) ;
DISJ_1_2_2(T).. X('3',T) =L= BIGM('1','2','2',T)*Z('2',T);
DISJ_2_2_2(T).. X('5',T) =L= BIGM('2','2','2',T)*Z('2',T);

DISJ_1_1_3(T).. X('13',T) =L= 0.75*X('9',T) + BIGM('1','1','3',T)*(1-Z('3',T));
DISJ_2_1_3(T).. X('13',T) =G= 0.75*X('9',T) - BIGM('2','1','3',T)*(1-Z('3',T));
DISJ_1_2_3(T).. X('9',T) =L= BIGM('1','2','3',T)*Z('3',T);
DISJ_2_2_3(T).. X('13',T) =L= BIGM('2','2','3',T)*Z('3',T);

DISJ_1_1_4(T).. X('14',T) =L= 1.5*LOG(1+X('10',T)) + BIGM('1','1','4',T)*(1-Z('4',T)) ;
DISJ_1_2_4(T).. X('10',T) =L= BIGM('1','2','4',T)*Z('4',T);
DISJ_2_2_4(T).. X('14',T) =L= BIGM('2','2','4',T)*Z('4',T);

DISJ_1_1_5(T).. X('15',T) =L= X('11',T) + BIGM('1','1','5',T)*(1-Z('5',T));
DISJ_2_1_5(T).. X('15',T) =G= X('11',T) - BIGM('2','1','5',T)*(1-Z('5',T));
DISJ_3_1_5(T).. X('15',T) =L= 0.5*X('12',T) + BIGM('3','1','5',T)*(1-Z('5',T));
DISJ_4_1_5(T).. X('15',T) =G= 0.5*X('12',T) - BIGM('4','1','5',T)*(1-Z('5',T));
DISJ_1_2_5(T).. X('11',T) =L= BIGM('1','2','5',T)*Z('5',T);
DISJ_2_2_5(T).. X('12',T) =L= BIGM('2','2','5',T)*Z('5',T);
DISJ_3_2_5(T).. X('15',T) =L= BIGM('3','2','5',T)*Z('5',T);

DISJ_1_1_6(T).. X('21',T) =L= 1.25*LOG(1+X('16',T)) + BIGM('1','1','6',T)*(1-Z('6',T)) ;
DISJ_1_2_6(T).. X('16',T) =L= BIGM('1','2','6',T)*Z('6',T);
DISJ_2_2_6(T).. X('21',T) =L= BIGM('2','2','6',T)*Z('6',T);

DISJ_1_1_7(T).. X('22',T) =L= 0.9*LOG(1+X('17',T)) + BIGM('1','1','7',T)*(1-Z('7',T)) ;
DISJ_1_2_7(T).. X('17',T) =L= BIGM('1','2','7',T)*Z('7',T);
DISJ_2_2_7(T).. X('22',T) =L= BIGM('2','2','7',T)*Z('7',T);

DISJ_1_1_8(T).. X('23',T) =L= LOG(1+X('14',T)) + BIGM('1','1','8',T)*(1-Z('8',T)) ;
DISJ_1_2_8(T).. X('14',T) =L= BIGM('1','2','8',T)*Z('8',T);
DISJ_2_2_8(T).. X('23',T) =L= BIGM('2','2','8',T)*Z('8',T);

DISJ_1_1_9(T).. X('24',T) =L= 0.9*X('18',T) + BIGM('1','1','9',T)*(1-Z('9',T));
DISJ_2_1_9(T).. X('24',T) =G= 0.9*X('18',T) - BIGM('2','1','9',T)*(1-Z('9',T));
DISJ_1_2_9(T).. X('18',T) =L= BIGM('1','2','9',T)*Z('9',T);
DISJ_2_2_9(T).. X('24',T) =L= BIGM('2','2','9',T)*Z('9',T);

DISJ_1_1_10(T).. X('25',T) =L= 0.6*X('19',T) + BIGM('1','1','10',T)*(1-Z('10',T));
DISJ_2_1_10(T).. X('25',T) =G= 0.6*X('19',T) - BIGM('2','1','10',T)*(1-Z('10',T));
DISJ_1_2_10(T).. X('19',T) =L= BIGM('1','2','10',T)*Z('10',T);
DISJ_2_2_10(T).. X('25',T) =L= BIGM('2','2','10',T)*Z('10',T);

DISJ_1_1_11(T).. X('26',T) =L= 1.1*LOG(1+X('20',T)) + BIGM('1','1','11',T)*(1-Z('11',T)) ;
DISJ_1_2_11(T).. X('20',T) =L= BIGM('1','2','11',T)*Z('11',T);
DISJ_2_2_11(T).. X('26',T) =L= BIGM('2','2','11',T)*Z('11',T);

DISJ_1_1_12(T).. X('37',T) =L= 0.9*X('21',T) + BIGM('1','1','12',T)*(1-Z('12',T));
DISJ_2_1_12(T).. X('37',T) =G= 0.9*X('21',T) - BIGM('2','1','12',T)*(1-Z('12',T));
DISJ_3_1_12(T).. X('37',T) =L= X('29',T) + BIGM('3','1','12',T)*(1-Z('12',T));
DISJ_4_1_12(T).. X('37',T) =G= X('29',T) - BIGM('4','1','12',T)*(1-Z('12',T));
DISJ_1_2_12(T).. X('21',T) =L= BIGM('1','2','12',T)*Z('12',T);
DISJ_2_2_12(T).. X('29',T) =L= BIGM('2','2','12',T)*Z('12',T);
DISJ_3_2_12(T).. X('37',T) =L= BIGM('3','2','12',T)*Z('12',T);

DISJ_1_1_13(T).. X('38',T) =L= LOG(1+X('22',T)) + BIGM('1','1','13',T)*(1-Z('13',T)) ;
DISJ_1_2_13(T).. X('22',T) =L= BIGM('1','2','13',T)*Z('13',T);
DISJ_2_2_13(T).. X('38',T) =L= BIGM('2','2','13',T)*Z('13',T);

DISJ_1_1_14(T).. X('39',T) =L= 0.7*LOG(1+X('27',T)) + BIGM('1','1','14',T)*(1-Z('14',T)) ;
DISJ_1_2_14(T).. X('27',T) =L= BIGM('1','2','14',T)*Z('14',T);
DISJ_2_2_14(T).. X('39',T) =L= BIGM('2','2','14',T)*Z('14',T);

DISJ_1_1_15(T).. X('40',T) =L= 0.65*LOG(1+X('28',T)) + BIGM('1','1','15',T)*(1-Z('15',T)) ;
DISJ_2_1_15(T).. X('40',T) =L= 0.65*LOG(1+X('31',T)) + BIGM('2','1','15',T)*(1-Z('15',T)) ;
DISJ_1_2_15(T).. X('28',T) =L= BIGM('1','2','15',T)*Z('15',T);
DISJ_2_2_15(T).. X('31',T) =L= BIGM('2','2','15',T)*Z('15',T);
DISJ_3_2_15(T).. X('40',T) =L= BIGM('3','2','15',T)*Z('15',T);

DISJ_1_1_16(T).. X('41',T) =L= X('32',T) + BIGM('1','1','16',T)*(1-Z('16',T));
DISJ_2_1_16(T).. X('41',T) =G= X('32',T) - BIGM('2','1','16',T)*(1-Z('16',T));
DISJ_1_2_16(T).. X('32',T) =L= BIGM('1','2','16',T)*Z('16',T);
DISJ_2_2_16(T).. X('41',T) =L= BIGM('2','2','16',T)*Z('16',T);

DISJ_1_1_17(T).. X('42',T) =L= X('33',T) + BIGM('1','1','17',T)*(1-Z('17',T));
DISJ_2_1_17(T).. X('42',T) =G= X('33',T) - BIGM('2','1','17',T)*(1-Z('17',T));
DISJ_1_2_17(T).. X('33',T) =L= BIGM('1','2','17',T)*Z('17',T);
DISJ_2_2_17(T).. X('42',T) =L= BIGM('2','2','17',T)*Z('17',T);

DISJ_1_1_18(T).. X('43',T) =L= 0.75*LOG(1+X('34',T)) + BIGM('1','1','18',T)*(1-Z('18',T)) ;
DISJ_1_2_18(T).. X('34',T) =L= BIGM('1','2','18',T)*Z('18',T);
DISJ_2_2_18(T).. X('43',T) =L= BIGM('2','2','18',T)*Z('18',T);

DISJ_1_1_19(T).. X('44',T) =L= 0.8*LOG(1+X('35',T)) + BIGM('1','1','19',T)*(1-Z('19',T)) ;
DISJ_1_2_19(T).. X('35',T) =L= BIGM('1','2','19',T)*Z('19',T);
DISJ_2_2_19(T).. X('44',T) =L= BIGM('2','2','19',T)*Z('19',T);

DISJ_1_1_20(T).. X('45',T) =L= 0.85*LOG(1+X('36',T)) + BIGM('1','1','20',T)*(1-Z('20',T)) ;
DISJ_1_2_20(T).. X('36',T) =L= BIGM('1','2','20',T)*Z('20',T);
DISJ_2_2_20(T).. X('45',T) =L= BIGM('2','2','20',T)*Z('20',T);

DISJ_1_1_21(T).. X('49',T) =L= LOG(1+X('47',T)) + BIGM('1','1','21',T)*(1-Z('21',T));
DISJ_1_2_21(T).. X('47',T) =L= BIGM('1','2','21',T)*Z('21',T);
DISJ_2_2_21(T).. X('49',T) =L= BIGM('2','2','21',T)*Z('21',T);

DISJ_1_1_22(T).. X('50',T) =L= 1.2*LOG(1+X('48',T)) + BIGM('1','1','22',T)*(1-Z('22',T)) ;
DISJ_1_2_22(T).. X('48',T) =L= BIGM('1','2','22',T)*Z('22',T);
DISJ_2_2_22(T).. X('50',T) =L= BIGM('2','2','22',T)*Z('22',T);

DISJ_1_1_23(T).. X('58',T) =L= 0.75*X('54',T) + BIGM('1','1','23',T)*(1-Z('23',T));
DISJ_2_1_23(T).. X('58',T) =G= 0.75*X('54',T) - BIGM('2','1','23',T)*(1-Z('23',T));
DISJ_1_2_23(T).. X('54',T) =L= BIGM('1','2','23',T)*Z('23',T);
DISJ_2_2_23(T).. X('58',T) =L= BIGM('2','2','23',T)*Z('23',T);

DISJ_1_1_24(T).. X('59',T) =L= 1.5*LOG(1+X('55',T)) + BIGM('1','1','24',T)*(1-Z('24',T)) ;
DISJ_1_2_24(T).. X('55',T) =L= BIGM('1','2','24',T)*Z('24',T);
DISJ_2_2_24(T).. X('59',T) =L= BIGM('2','2','24',T)*Z('24',T);

DISJ_1_1_25(T).. X('60',T) =L= X('56',T) + BIGM('1','1','25',T)*(1-Z('25',T));
DISJ_2_1_25(T).. X('60',T) =G= X('56',T) - BIGM('2','1','25',T)*(1-Z('25',T));
DISJ_3_1_25(T).. X('60',T) =L= 0.5*X('57',T) + BIGM('3','1','25',T)*(1-Z('25',T));
DISJ_4_1_25(T).. X('60',T) =G= 0.5*X('57',T) - BIGM('4','1','25',T)*(1-Z('25',T));
DISJ_1_2_25(T).. X('56',T) =L= BIGM('1','2','25',T)*Z('25',T);
DISJ_2_2_25(T).. X('57',T) =L= BIGM('2','2','25',T)*Z('25',T);
DISJ_3_2_25(T).. X('60',T) =L= BIGM('3','2','25',T)*Z('25',T);

DISJ_1_1_26(T).. X('66',T) =L= 1.25*LOG(1+X('61',T)) + BIGM('1','1','26',T)*(1-Z('26',T)) ;
DISJ_1_2_26(T).. X('61',T) =L= BIGM('1','2','26',T)*Z('26',T);
DISJ_2_2_26(T).. X('66',T) =L= BIGM('2','2','26',T)*Z('26',T);

DISJ_1_1_27(T).. X('67',T) =L= 0.9*LOG(1+X('62',T)) + BIGM('1','1','27',T)*(1-Z('27',T)) ;
DISJ_1_2_27(T).. X('62',T) =L= BIGM('1','2','27',T)*Z('27',T);
DISJ_2_2_27(T).. X('67',T) =L= BIGM('2','2','27',T)*Z('27',T);

DISJ_1_1_28(T).. X('68',T) =L= LOG(1+X('59',T)) + BIGM('1','1','28',T)*(1-Z('28',T)) ;
DISJ_1_2_28(T).. X('59',T) =L= BIGM('1','2','28',T)*Z('28',T);
DISJ_2_2_28(T).. X('68',T) =L= BIGM('2','2','28',T)*Z('28',T);

DISJ_1_1_29(T).. X('69',T) =L= 0.9*X('63',T) + BIGM('1','1','29',T)*(1-Z('29',T));
DISJ_2_1_29(T).. X('69',T) =G= 0.9*X('63',T) - BIGM('2','1','29',T)*(1-Z('29',T));
DISJ_1_2_29(T).. X('63',T) =L= BIGM('1','2','29',T)*Z('29',T);
DISJ_2_2_29(T).. X('69',T) =L= BIGM('2','2','29',T)*Z('29',T);

DISJ_1_1_30(T).. X('70',T) =L= 0.6*X('64',T) + BIGM('1','1','30',T)*(1-Z('30',T));
DISJ_2_1_30(T).. X('70',T) =G= 0.6*X('64',T) - BIGM('2','1','30',T)*(1-Z('30',T));
DISJ_1_2_30(T).. X('64',T) =L= BIGM('1','2','30',T)*Z('30',T);
DISJ_2_2_30(T).. X('70',T) =L= BIGM('2','2','30',T)*Z('30',T);

*Constraints in disjunct 2
DISJ2_1_Synthesis(I,T).. COST(I,T) =L= FC(I,T) + BIGM2_1(I,T)*(1-R(I,T));
DISJ2_2_Synthesis(I,T).. COST(I,T) =G= FC(I,T) - BIGM2_2(I,T)*(1-R(I,T));
*****************

Logic_Z(I,T,TAU)$(ORD(T) LT ORD(TAU))..                   Z(I,T) =L= Z(I,TAU);
Logic_R(I,T,TAU)$(ORD(TAU) NE ORD(T))..                   R(I,T) + R(I,TAU) =L= 1;
Logic_ZR(I,T)..                                           Z(I,T) =L= R(I,T) + Z(I,T-1) + Z(I,T-2);

*Design Specifications
D1(T)..  Z('1',T) + Z('2',T)                              =E= 1;

*Logic Cuts (that were deduced bZ inspection from the superstructure -- used to aid in the optimization)

L1(T)..  -Z('3',T) + Z('6',T) + Z('7',T)                  =G= 0;
L2(T)..  -Z('6',T) + Z('12',T)                            =G= 0;
L3(T)..  -Z('7',T) + Z('13',T)                            =G= 0;
L4(T)..  -Z('4',T) + Z('8',T)                             =G= 0;
L5(T)..  -Z('8',T) + Z('14',T) + Z('15',T)                =G= 0;
L6(T)..  -Z('5',T) + Z('9',T) + Z('10',T) + Z('11',T)     =G= 0;
L7(T)..  -Z('9',T) + Z('15',T)                            =G= 0;
L8(T)..  -Z('10',T) + Z('16',T) + Z('17',T)               =G= 0;
L9(T)..  -Z('11',T) + Z('18',T) + Z('19',T) + Z('20',T)   =G= 0;
L10(T).. -Z('3',T) + Z('1',T) + Z('2',T)                  =G= 0;
L11(T).. -Z('4',T) + Z('1',T) + Z('2',T)                  =G= 0;
L12(T).. -Z('5',T) + Z('1',T) + Z('2',T)                  =G= 0;
L13(T).. -Z('6',T) + Z('3',T)                             =G= 0;
L14(T).. -Z('7',T) + Z('3',T)                             =G= 0;
L15(T).. -Z('8',T) + Z('4',T)                             =G= 0;
L16(T).. -Z('9',T) + Z('5',T)                             =G= 0;
L17(T).. -Z('10',T) + Z('5',T)                            =G= 0;
L18(T).. -Z('11',T) + Z('5',T)                            =G= 0;
L19(T).. -Z('12',T) + Z('6',T)                            =G= 0;
L20(T).. -Z('13',T) + Z('7',T)                            =G= 0;
L21(T).. -Z('14',T) + Z('8',T)                            =G= 0;
L22(T).. -Z('15',T) + Z('8',T)                            =G= 0;
L23(T).. -Z('16',T) + Z('10',T)                           =G= 0;
L24(T).. -Z('17',T) + Z('10',T)                           =G= 0;
L25(T).. -Z('18',T) + Z('11',T)                           =G= 0;
L26(T).. -Z('19',T) + Z('11',T)                           =G= 0;
L27(T).. -Z('20',T) + Z('11',T)                           =G= 0;

L28(T).. -Z('20',T) + Z('21',T) + Z('22',T)               =G= 0;
L29(T).. -Z('23',T) + Z('26',T) + Z('27',T)               =G= 0;
L30(T).. -Z('24',T) + Z('28',T)                           =G= 0;
L31(T).. -Z('21',T) + Z('20',T)                           =G= 0;
L32(T).. -Z('22',T) + Z('20',T)                           =G= 0;
L33(T).. -Z('26',T) + Z('23',T)                           =G= 0;
L34(T).. -Z('27',T) + Z('23',T)                           =G= 0;
L35(T).. -Z('28',T) + Z('24',T)                           =G= 0;
L36(T).. -Z('29',T) + Z('25',T)                           =G= 0;
L37(T).. -Z('30',T) + Z('25',T)                           =G= 0;

* Bounds
X.UP('1',T) = 40;
X.UP('12',T) = 30;
X.UP('29',T) = 20;
X.UP('30',T) = 20;
X.UP('57',T) = 30;

MODEL RETRO_8_SYNTH_30_MULTI_BIGM /ALL/;

OPTION LIMROW = 476;
OPTION LIMCOL = 4;
*OPTION SOLPRINT = OFF ;
*OPTION SYSOUT   = OFF ;
OPTION OPTCR = 0;
OPTION OPTCA = 0;
OPTION ITERLIM = 100000000;
OPTION RESLIM = 10800;
OPTION MIP = CPLEX;
OPTION NLP = conopt;
OPTION RMINLP = conopt;
OPTION MINLP  = dicopt;

*SOLVE SYNTH_30_MULTI_BIGM USING RMINLP MAXIMIZING obj;

SYNTH_30_MULTI_BIGM.NODLIM = 1000000;
SYNTH_30_MULTI_BIGM.OPTFILE = 1;

SOLVE SYNTH_30_MULTI_BIGM USING MINLP MAXIMIZING obj;